@@ -1,14 +1,17 @@
 from __future__ import annotations
 
 import logging
-from ctypes import Structure
+from ctypes import POINTER, Structure
 from functools import partial
-from typing import Callable, Type, TypeVar, overload, Union, Sequence, Tuple, Literal
+from typing import Callable, Literal, Sequence, Tuple, Type, TypeVar, Union, overload
 
 # noinspection PyUnresolvedReferences, PyProtectedMember
-from typing_extensions import _AnnotatedAlias, get_type_hints, get_args
+from typing_extensions import _AnnotatedAlias, get_args, get_type_hints
 
 from einspect.protocols.type_parse import convert_type_hints, fix_ctypes_generics
+from einspect.types import _SelfPtr
+
+__all__ = ("struct",)
 
 log = logging.getLogger(__name__)
 
@@ -16,8 +19,6 @@ _T = TypeVar("_T", bound=Type[Structure])
 
 FieldsType = Sequence[Union[Tuple[str, type], Tuple[str, type, int]]]
 
-_TYPE_REPLACED = object()
-
 
 @overload
 def struct(*, fields: FieldsType) -> Callable[[_T], _T]:
@@ -42,21 +43,30 @@ def struct(cls: _T | None = None, fields: FieldsType | None = None):
 def _struct(cls: _T, __fields: FieldsType | None = None) -> _T:
     """Decorator to declare _fields_ on Structures via type hints."""
     # if fields provided, replace type hints with temp sentinel
-    fields_overrides = {
-        tup[0]: tup for tup in __fields or ()
-    }
+    fields_overrides = {}
+    for tup in __fields or ():
+        f_name, f_type, *_ = tup
+        f_ls = list(tup)
+        # Convert SelfPtr types to POINTER(cls)
+        if f_type is _SelfPtr:
+            f_ls[1] = POINTER(cls)  # type: ignore
+
+        fields_overrides[f_name] = tuple(f_ls)
+
     if __fields is not None:
         for tup in __fields:
             # This is to prevent errors during get_type_hints if there is an override
             cls.__annotations__[tup[0]] = None
 
     fields = []
+    # Locals dict for type hint resolution
+    hint_locals = {cls.__name__: cls}
     try:
-        hints = get_type_hints(cls, include_extras=True)
-    except TypeError:
+        hints = get_type_hints(cls, None, hint_locals, include_extras=True)
+    except (TypeError, NameError):
         # Normalize annotations of py_object subscripts
-        fix_ctypes_generics(cls.__annotations__)
-        hints = get_type_hints(cls, include_extras=True)
+        fix_ctypes_generics(cls.__annotations__, cls.__name__)
+        hints = get_type_hints(cls, None, hint_locals, include_extras=True)
 
     for name, type_hint in hints.items():
         # Use override if exists
@@ -84,10 +94,12 @@ def _struct(cls: _T, __fields: FieldsType | None = None) -> _T:
         type_hint = convert_type_hints(type_hint, cls)
         fields.append((name, type_hint))
 
-    # We have to only set this once as _fields_ is final
+    # We must only set this once as _fields_ is final
     try:
         cls._fields_ = fields
-    except TypeError as e:
-        raise TypeError(f"Failed to set _fields_ on {cls.__name__}: {fields}") from e
+    except (TypeError, AttributeError) as err:
+        raise TypeError(
+            f"Failed to set _fields_ ({fields}) on {cls.__name__} -> {err}"
+        ) from err
 
     return cls
