@@ -3,9 +3,9 @@ from __future__ import annotations
 
 import warnings
 from types import MappingProxyType
-from typing import Final, Type, TypeVar, overload, Any
+from typing import Any, Final, TypeVar, overload
 
-from einspect.views.view_base import View, REF_DEFAULT
+from einspect.views.view_base import REF_DEFAULT, View
 from einspect.views.view_bool import BoolView
 from einspect.views.view_dict import DictView
 from einspect.views.view_float import FloatView
@@ -15,11 +15,13 @@ from einspect.views.view_mapping_proxy import MappingProxyView
 from einspect.views.view_set import SetView
 from einspect.views.view_str import StrView
 from einspect.views.view_tuple import TupleView
+from einspect.views.view_type import TypeView
 
 __all__ = ("view",)
 
-VIEW_TYPES: Final[dict[type, Type[View]]] = {
+VIEW_TYPES: Final[dict[type, type[View]]] = {
     object: View,
+    type: TypeView,
     int: IntView,
     bool: BoolView,
     float: FloatView,
@@ -36,6 +38,9 @@ VIEW_TYPES: Final[dict[type, Type[View]]] = {
 _KT = TypeVar("_KT")
 _VT = TypeVar("_VT")
 
+# TypeView
+_Type = TypeVar("_Type", bound=type)
+
 # Base case
 _T = TypeVar("_T")
 
@@ -92,6 +97,11 @@ def view(obj: float, ref: bool = REF_DEFAULT) -> FloatView:
     ...
 
 
+@overload
+def view(obj: _Type, ref: bool = REF_DEFAULT) -> TypeView[_Type]:
+    ...
+
+
 def view(obj, ref: bool = REF_DEFAULT):
     """
     Create a view onto a Python object.
