@@ -22,12 +22,31 @@ _T = TypeVar("_T")
 _Fn = TypeVar("_Fn", bound=Callable)
 
 
+def impl(cls: Type[_T]) -> Callable[[_Fn], _Fn]:
+    """Decorator for implementing methods on built-in types."""
+    if not isinstance(cls, type):
+        raise TypeError("cls must be a type")
+
+    t_view = TypeView(cls)
+
+    def wrapper(func: _Fn) -> _Fn:
+        if isinstance(func, property):
+            name = func.fget.__name__
+        else:
+            name = func.__name__
+
+        t_view[name] = func
+        return func
+
+    return wrapper
+
+
 class TypeView(VarView[_T, None, None]):
     _pyobject: PyTypeObject[_T]
 
     def __init__(self, obj: _T, ref: bool = REF_DEFAULT) -> None:
+        """Create a new TypeView."""
         super().__init__(obj, ref)
-        self._store = []
 
     @property
     def immutable(self) -> bool:
@@ -108,22 +127,3 @@ class TypeView(VarView[_T, None, None]):
             setattr(self._pyobject, key, value)
             return
         super().__setattr__(key, value)
-
-
-def impl(cls: Type[_T]) -> Callable[[_Fn], _Fn]:
-    """Decorator for implementing methods on built-in types."""
-    if not isinstance(cls, type):
-        raise TypeError("cls must be a type")
-
-    t_view = TypeView(cls)
-
-    def wrapper(func: _Fn) -> _Fn:
-        if isinstance(func, property):
-            name = func.fget.__name__
-        else:
-            name = func.__name__
-
-        t_view[name] = func
-        return func
-
-    return wrapper
